@@ -36,8 +36,7 @@
 
 
 int
-dwarf_arrayorder (die)
-     Dwarf_Die *die;
+dwarf_arrayorder (Dwarf_Die *die)
 {
   Dwarf_Attribute attr_mem;
   Dwarf_Word value;
