@@ -35,7 +35,7 @@
 #include ELFUTILS_HEADER(dwelf)
 #include <gelf.h>
 #include "libeu.h"
-#include "system.h"
+#include "printversion.h"
 
 /* Name and version of program.  */
 ARGP_PROGRAM_VERSION_HOOK_DEF = print_version;
